=============
flask-autoapi
=============
A framework based on flask_restful and peewee.  

It could create API and Doc automatically with ORM Model.


Install
=============
    npm install apidoc -g
    
    pip install flask-autoapi



Run
=============
    python test.py doc

    python test.py runserver